;+
;NAME:
; thm_mk_data_dir
;PURPOSE:
; Given the root directory for themis data, and a themis data
; filename, create a directory structure.
;CALLING SEQUENCE:
; path = thm_mk_data_dir(filename, themis_data_dir=themis_data_dir)
;INPUT:
; filename=The cdf filename that you are looking for
;OUTPUT:
; path = the string for the data path
;KEYWORDS:
; themis_data_dir= the root directory, the default is THEMIS_DATA_DIR
; name_only= only return the name, don't try to create directories
;HISTORY:
; 14-nov-2006, jmm, jimm@ssl.berkeley.edu
; 12-dec-2006, jmm, No need for slahses to be checked... concat_dir is
;                   not needed
;
;$LastChangedBy J McTiernan $
;$LastChangedDate 12-Dec-2006 $
;$LastChangedRevision$ 
;$URL mailto:jimm@ssl.berkeley.edu $
;
;-
Function thm_mk_data_dir, filename0, themis_data_dir = themis_data_dir, $
                          name_only = name_only, _extra = _extra

  otp = -1
  slash = '/'
  filename = file_basename(filename0)
  dotcdf = strpos(filename, '.cdf')
  If(dotcdf[0] Eq -1) Then Begin
    message, /info, filename+' is not a cdf file'
    Return, -1
  Endif
  xxx = strmid(filename, 0, dotcdf) ;this gets the year
  dirs = strsplit(xxx, '_', /extract)
;Drop extraneous numbers; e.g., tha_l1_eir_006x16_20060816_v01.cdf,
;but keep different stations: eg,. thg_l2_mag_bmls_20060816_v01.cdf
  If(n_elements(dirs) Eq 6 And dirs[0] Ne 'thg') Then $
    dirs = dirs[[0, 1, 2, 4, 5]]
;drop the version number, and truncate the year
  ndirs = n_elements(dirs)
  If(ndirs Gt 2) Then Begin
    dirs = dirs[0:ndirs-2]
    ndirs = n_elements(dirs)
    dirs[ndirs-1] = strmid(dirs[ndirs-1], 0, 4)
  Endif
;build up the name
  If(keyword_set(themis_data_dir)) Then thdd = themis_data_dir $
  Else thdd = getenv('THEMIS_DATA_DIR')
  otp = concat_dir(thdd, dirs[0]) ;because there may not be a slash.....
  If(ndirs Gt 1) Then For j = 1, ndirs-1 Do otp = otp+slash+dirs[j]
  otp = otp+slash
  If(Not keyword_set(name_only)) Then file_mkdir, otp
;No need to build up the directory structure, piece by piece
  Return, otp
End
