;+
;NAME:
;thm_ui_plot_data
;PURPOSE:
;A widget interface to load CDF data for whatever instrument
;CALLING SEQUENCE:
;thm_ui_plot_data, st_time, en_time, data_struct, datatype
;INPUT:
;st_time, en_time = start and end times in seconds from
;                   1-jan-1970 0:00
;data_ss, the subscripts for the data structures that are to be
;         plotted, for tplot data
;datatype, the type of data, a string, of form 'thg_mag', for example
;OUTPUT:
;None explicit, it just plots the data
;HISTORY:
;13-Nov-2006, jmm, jimm@ssl.berkeley.edu, currently only calls the
;             stackmagplot routine, and needs a different mastercdf
;             path, 
;
;$LastChangedBy$ J McTiernan
;$LastChangedDate$ 5-Dec-2006
;$LastChangedRevision$ Added comments
;$URL$ mailto:jimm@ssl.berkeley.edu
;
;-
Pro thm_ui_plot_data, st_time, en_time, data_ss, datatype0, spacecraft0, $
                      plot_type

  @tplot_com

;Put a catch here to insure that the common block is returned in its
;original state
  err_xxx = 0
  catch, err_xxx
  If(err_xxx Ne 0) Then Begin
    catch, /cancel
    message, /info, 'Error'
    help, /last_message, output = err_msg
    For j = 0, n_elements(err_msg)-1 Do print, err_msg[j]
    thm_ui_reset_common_block, /restore
    Return
  Endif

  datatype = strlowcase(strcompress(datatype0, /remove_all))
  spacecraft = strlowcase(strcompress(spacecraft0, /remove_all))
;put the assigned data structure into the tplot common block
  thm_ui_reset_common_block, data_ss
  If(spacecraft Eq 'thg' And datatype Eq 'mag') Then Begin
    date = time_string(st_time)
    duration = (en_time-st_time)/86400.0d0
    If(plot_type Eq 'PNG') Then pngx = 1 Else pngx = 0
;    thg_mag_stackplot, date, duration, $
;      mastercdf_path = '~mattd/GBO/mastercdfs/', /no_data_load, $
;      make_png = pngx, no_expose = pngx
;      thg_mag_stackplot, date, duration, mastercdf_path = 'c:\socware\idl\mastercdfs\', /no_data_load,$
;        make_png = pngx, no_expose = pngx
    thm_gmag_stackplot, date, duration, /no_data_load, $
      make_png = pngx, no_expose = pngx
  Endif Else message, /info, datatype+' Not Implemented'
  thm_ui_reset_common_block, /restore
  Return
End
