;+
;NAME:
; thm_ui_tselect
;PURPOSE:
; A list widget for time selection, this is a blocking widget, it must
; be exited for anything to happen
;CALLING SEQUENCE:
; thm_ui_teslect
;INPUT:
; none
;OUTPUT:
; the selected time is held in the common block saved_time_sel
;HISTORY:
; sep-2006,  jmm,  jimm@ssl.berkeley.edu
;
;$LastChangedBy$ J McTiernan
;$LastChangedDate$ 5-Dec-2006
;$LastChangedRevision$ Added comments
;$URL$ mailto:jimm@ssl.berkeley.edu
;
;-
Common saved_time_sel, time_selected
pro thm_ui_tselect_event, event
  Common saved_time_sel, time_selected

  this_year = long(strmid(!stime, 7, 4))
  n_years = this_year+2-2005
  xyr = 2005+indgen(n_years)
  xmo = 1+indgen(12)
  pmo = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', $
         'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
  xdy = 1+indgen(31)
  xhr = indgen(24)
  xmn = indgen(60)
  xsc = indgen(60)
;what happened?
  widget_control, event.id, get_uval = uval
  Case uval Of
    'EXIT': widget_control, event.top, /destroy
    'YR': begin
; get state
      widget_control, event.top, get_uval = state, /no_copy
; get year index
      pindex = widget_info(state.wyr, /list_select)
; update date
      state.ptstruct.year = xyr[pindex]
; save state
      time_selected = state.ptstruct
      widget_control, event.top, set_uval = state, /no_copy
    End
    'MO': begin
      widget_control, event.top, get_uval = state, /no_copy
      pindex = widget_info(state.wmo, /list_select)
      state.ptstruct.month = xmo[pindex]
      time_selected = state.ptstruct
      widget_control, event.top, set_uval = state, /no_copy
    End 
    'DY': begin
      widget_control, event.top, get_uval = state, /no_copy
      pindex = widget_info(state.wdy, /list_select)
      state.ptstruct.date = xdy[pindex]
      time_selected = state.ptstruct
      widget_control, event.top, set_uval = state, /no_copy
   End 
   'HR': begin
      widget_control, event.top, get_uval = state, /no_copy
      pindex = widget_info(state.whr, /list_select)
      state.ptstruct.hour = xhr[pindex]
      time_selected = state.ptstruct
      widget_control, event.top, set_uval = state, /no_copy
   End 
   'MN': begin
     widget_control, event.top, get_uval = state, /no_copy
     pindex = widget_info(state.wmn, /list_select)
     state.ptstruct.min = xmn[pindex]
     time_selected = state.ptstruct
     widget_control, event.top, set_uval = state, /no_copy
   End 
   'SC': begin
     widget_control, event.top, get_uval = state, /no_copy
     pindex = widget_info(state.wsc, /list_select)
     state.ptstruct.sec = xsc[pindex]
     time_selected = state.ptstruct
     widget_control, event.top, set_uval = state, /no_copy
   End 
 Endcase
 Return
End

Pro thm_ui_tselect
  Common saved_time_sel, time_selected
;create the widget
  thmtw = widget_base(/col, title = 'THM time interval', $
                     tlb_frame_attr = 1)
;file browser
  timew = widget_base(thmtw, /col, frame = 5, /align_center)
  flabel = widget_label(timew, value = 'Choose Date and time')

  this_year = long(strmid(!stime, 7, 4))
  n_years = this_year+2-2005

  pyr = strcompress(string(2005+indgen(n_years)))
;  pmo = strcompress(string(1+indgen(12)))
  pmo = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', $
         'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec']
  pdy = strcompress(string(1+indgen(31)))
  phr = strcompress(string(indgen(24)))
  pmn = strcompress(string(indgen(60)))
  psc = strcompress(string(indgen(60)))
;  year
  yrwid = widget_base(timew, /row, /align_center, /frame)
  yrlabel = widget_label(yrwid, value = ' year')
  yrlist = widget_list(yrwid, value = pyr, xsiz = 5, $
                       ysiz = 5, uval = 'YR')
  widget_control, yrlist, set_list_top = (n_elements(pyr)-5) > 0
  
;  month
  mowid = widget_base(timew, /row, /align_center, /frame)
  molabel = widget_label(mowid, value = 'month')
  molist = widget_list(mowid, value = pmo, xsiz = 4, ysiz = 5, $
                       uval = 'MO')

;  day
  dywid = widget_base(timew, /row, /align_center, /frame)
  dylabel = widget_label(dywid, value = '  day')
  dylist = widget_list(dywid, value = pdy, xsiz = 4, ysiz = 5, $
                       uval = 'DY')
; hour
  hrwid = widget_base(timew, /row, /align_center, /frame)
  hrlabel = widget_label(hrwid, value = ' hour')
  hrlist = widget_list(hrwid, value = phr, xsiz = 4, ysiz = 5, $
                       uval = 'HR')
; minute
  mnwid = widget_base(timew, /row, /align_center, /frame)
  mnlabel = widget_label(mnwid, value = '  min')
  mnlist = widget_list(mnwid, value = pmn, xsiz = 4, ysiz = 5, $
                       uval = 'MN')
; second
  scwid = widget_base(timew, /row, /align_center, /frame)
  sclabel = widget_label(scwid, value = '  sec')
  sclist = widget_list(scwid, value = psc, xsiz = 4, ysiz = 5, $
                       uval = 'SC')
;  exit button
  butwid = widget_base(thmtw, /col, /align_center)
  exbut = widget_button(butwid, val = ' Accept and Close ', uval = 'EXIT', $
                        /align_center)

  y = time_struct('1970-01-01/00:00:00')
  state={wyr:yrlist, wmo:molist, wdy:dylist, whr:hrlist, $
         wmn:mnlist, wsc:sclist, $
         ptstruct:y}
  widget_control, thmtw, set_uval = state, /no_copy

;  realize
  widget_control, thmtw, /realize
  xmanager, 'thm_ui_tselect', thmtw
End
