;+
;NAME:
; yesno_widget_fn
;PURPOSE:
; Simple widget that asks for a yes or no
;CALLING SEQUENCE:
; yn=yesno_widget_fn(title, list = list, _extra = _extra)
;INPUT:
; title = a title, or a question
;OUTPUT:
; yn = 0 for no, 1 for yes
;KEYWORDS:
; list, a string array to put in the widget, as an aid
;HISTORY:
; 27-nov-2006, jmm, jimm@ssl.berkeley.edu
;
;$LastChangedBy$ J McTiernan
;$LastChangedDate$ 5-Dec-2006
;$LastChangedRevision$ Added comments
;$URL$ mailto:jimm@ssl.berkeley.edu
;
;-

Pro yesno_widget_event, event
  common yesno_widget_private, yn_sav, yes_always
  widget_control, event.id, get_uval = uval
  Case uval Of
    'YES':Begin
      widget_control, event.top, get_uval = state
      state.yesno = 1b
      yn_sav = 1b
      yes_always = 0b
      state.yesno_all = 0b
      widget_control, event.top, /destroy
    End
    'YES_TO_ALL':Begin
      widget_control, event.top, get_uval = state
      state.yesno = 1b
      yn_sav = 1b
      yes_always = 1b
      state.yesno_all = 1b
      widget_control, event.top, /destroy
    End
    'NO':Begin
      widget_control, event.top, get_uval = state
      state.yesno = 0b
      yn_sav = 0b
      yes_always = 0b
      state.yesno_all = 0b
      widget_control, event.top, /destroy
    End
  Endcase
Return
End
Pro yesno_widget, title_in, list = list

  master = widget_base(/col, title = title_in, $
                       /tlb_frame_attr)

;list if needed
  If(is_string(list)) Then Begin
    listid = widget_base(master, /row, /align_center, /frame)
    flabel = widget_label(listid, value = 'list')
    lvllist = widget_text(listid, value = list, xsiz = strlen(list[0]), $
                          ysiz = n_elements(list) < 10, uval = 'LIST')
  Endif
  yes_button = widget_button(master, val = 'YES', uval = 'YES', /align_center)
  no_button = widget_button(master, val = 'NO', uval = 'NO', /align_center)
  yes_all_button = widget_button(master, val = 'YES, AND DON''T ASK AGAIN', $
                                 uval = 'YES_TO_ALL', /align_center)
  state = {master:master, yesno:0b, yesno_all:0b}
  widget_control, master, set_uval = state, /no_copy
  widget_control, master, /realize
  xmanager, 'yesno_widget', master
  Return
End
Function yesno_widget_fn, title, list = list, _extra = _extra
  common yesno_widget_private, yn_sav, yes_always
  If(n_elements(yes_always) Gt 0) Then Begin
    If(yes_always) Then yn = 1b Else Begin
      yesno_widget, title, list = list, _extra = _extra
      yn = yn_sav
    Endelse
  Endif Else Begin
    yesno_widget, title, list = list, _extra = _extra
    yn = yn_sav
  Endelse

  Return, yn
End
