;+
;Procedure: THM_LOAD_GMAG,station
;
;keywords:
;   TRANGE= (Optional) Time range of interest  (2 element array).
;   /VERBOSE : set to output some useful info
;   /SUBTRACT_AVERAGE  ;
;Example:
;   thg_load_mag,'bmls'
;Notes:
;  This routine is (should be) platform independent.
;
; $LastChangedBy: davin-win $
; $LastChangedDate: 2006-12-15 12:29:37 -0800 (Fri, 15 Dec 2006) $
; $LastChangedRevision: 107 $
; $URL: svn+ssh://thmsvn@ambrosia.ssl.berkeley.edu/repos/thmsoc/trunk/idl/themis/ground/thm_load_gmag.pro $
;-
pro thm_load_gmag,stations,trange=trange,verbose=verbose,all=all $
   ,subtract_average=subavg,downloadonly=downloadonly

themis_init

; Valid stations:
vstats='bmls ccnv drby ekat fsim fsmi fykn fyts gako gbay gill hots kapu kian loys mcgr pgeo pina pine ptrs rank rmus swno taho tbd1 tpas ukia whit'
vstats=strsplit(vstats,' ',/extract)

if not keyword_set(stations) then stations='*'

stats = strfilter(vstats,stations,match_delim=' ')

if not keyword_set(stats) then  begin
   print,'Input must be one or more of the following strings:
   print,vstats
   return
endif

if keyword_set(verbose) then printdat,stats,/value,'Stations'


for i=0,n_elements(stats)-1 do begin    ; loop over all stations
  station = stats[i]

  ; Although these file names appear platform dependent, it works well on MS windows! Please don't change
  relpath = 'thg/l2/mag/'+ station + '/'
  prefix = 'thg_l2_mag_' + station + '_'
  ending = '_v01.cdf'
  relpathnames = file_dailynames(relpath,prefix,ending,/YEARDIR,trange=trange)


  ; get files:
  files = file_retrieve(relpathnames,local_root=!themis.local_data_dir,remote_root=!themis.remote_data_dir)

  if keyword_set(verbose) then  print,files


  if  keyword_set(downloadonly) then continue

  cdf2tplot,/all,varnames=vars,file=files,verbose=verbose     ; load data into tplot variables
  varname = 'thg_mag_'+station
  options,/default,varname,ytitle=station+'!cB (nT)',constant=0.

  if keyword_set(subavg) then begin
      p=0
      get_data,varname,ptr=p,alim=alim
      str_element,alim,'cdf.

      *p.y -= (replicate(1,n_elements(*p.x)) # average(*p.y,1,/double) )
  endif



endfor

end

